@@ -78,8 +78,8 @@ var network = {
           base_uri : "https://accounts.google.com/o/",
           //redirect_uri : "urn:ietf:wg:oauth:2.0:oob:auto",
           scope : "https://www.googleapis.com/auth/carddav https://www.googleapis.com/auth/calendar",
-          client_id : "689460414096-e4nddn8tss5c59glidp4bc0qpeu3oper.apps.googleusercontent.com",
-          client_secret : "LeTdF3UEpCvP1V3EBygjP-kl",
+          client_id : dav.sync.prefSettings.getCharPref("OAuth2_ClientID"),
+          client_secret : dav.sync.prefSettings.getCharPref("OAuth2_ClientSecret"),
         }
         break;
       
@@ -87,7 +87,7 @@ var network = {
         return null;
     }
     
-    let oauth = new OAuth2(config.base_uri, config.scope, config.client_id, config.client_secret);
+    let oauth = new OAuth2(config.base_uri + "oauth2/auth", config.base_uri + "oauth2/token", config.scope, config.client_id, config.client_secret);
     oauth.requestWindowFeatures = "chrome,private,centerscreen,width=500,height=750";
 
     //the v2 endpoints are different and would need manual override
