@@ -353,9 +353,8 @@ var sync = {
                             }
                         }
 
-                        // Update color from server (skip if nolightning, no
-                        // need to run into error when hasTarget() throws).
-                        if (color && job == "cal" && TbSync.lightning.isAvailable()) {
+                        // Update color from server.
+                        if (color && job == "cal") {
                             color = color.textContent.substring(0,7);
                             folderData.setFolderProperty("targetColor", color);
                             
@@ -406,7 +405,7 @@ var sync = {
         // add connection data to syncData
         syncData.connectionData = new dav.network.ConnectionData(syncData);
 
-        // add target to syncData (getTarget() will throw "nolightning" if lightning missing)
+        // add target to syncData
         let hadTarget;
         try {
             // accessing the target for the first time will check if it is avail and if not will create it (if possible)
@@ -541,7 +540,7 @@ var sync = {
             let id = cards.multi[c].href;
             if (id !==null) {
                 //valid
-                let card = syncData.target.getItemFromProperty("X-DAV-HREF", id);
+                let card = await syncData.target.getItemFromProperty("X-DAV-HREF", id);
                 if (cards.multi[c].status == "200") {
                     //MOD or ADD
                     let etag = dav.tools.evaluateNode(cards.multi[c].node, [["d","prop"], ["d","getetag"]]);
@@ -636,7 +635,7 @@ var sync = {
 
                 if (cards.multi[c].status == "200" && etag !== null && id !== null /* && ctype !== null */) { //we do not actually check the content of ctype - but why do we request it? iCloud seems to send cards without ctype
                     vCardsFoundOnServer.push(id);
-                    let card = syncData.target.getItemFromProperty("X-DAV-HREF", id);
+                    let card = await syncData.target.getItemFromProperty("X-DAV-HREF", id);
                     if (!card) {
                         //if the user deleted this card (not yet send to server), do not add it again
                         if (!localDeletes.includes(id)) {
@@ -740,39 +739,24 @@ var sync = {
                 if (syncData.foundMailingListsDuringDownSync.hasOwnProperty(listID)) {
                     l++;
                     
-                    let list = syncData.target.getItemFromProperty("X-DAV-HREF", listID);
+                    let list = await syncData.target.getItemFromProperty("X-DAV-HREF", listID);
                     if (!list.isMailList)
                         continue;
-                    
-                    let currentMembers = list.getMembersPropertyList("X-DAV-UID");
-                    
+                                        
                     //CardInfo contains the name and the X-DAV-UID list of the members
                     let vCardInfo = dav.tools.getGroupInfoFromCardData(syncData.foundMailingListsDuringDownSync[listID].vCardData, syncData.target);
                     let oCardInfo = dav.tools.getGroupInfoFromCardData(syncData.foundMailingListsDuringDownSync[listID].oCardData, syncData.target);
 
                     // Smart merge: oCardInfo contains the state during last sync, vCardInfo is the current state.
-                    // By comparing we can learn, which member was deleted by the server (in old but not in new).
+                    // By comparing we can learn, which member was deleted by the server (in old but not in new),
+                    // and which one was added (in new but not in old)
                     let removedMembers = oCardInfo.members.filter(e => !vCardInfo.members.includes(e));
-                     
-                    // The new list from the server is taken.
-                    let newMembers = vCardInfo.members;
-                    
-                    // Any member in current but not in new is added.
-                    for (let member of currentMembers) {
-                        if (!newMembers.includes(member) && !removedMembers.includes(member)) 
-                            newMembers.push(member);
-                    }
+                    let newMembers = vCardInfo.members.filter(e => !oCardInfo.members.includes(e));
 
-                    // Remove local deletes.
-                    for (let member of oCardInfo.members) {
-                        if (!currentMembers.includes(member)) 
-                            newMembers = newMembers.filter(e => e != member);
-                    }
-                    
                     // Check that all new members have an email address (fix for bug 1522453)
                     let m=0;
                     for (let member of newMembers) {
-                        let card = syncData.target.getItemFromProperty("X-DAV-UID", member);
+                        let card = await syncData.target.getItemFromProperty("X-DAV-UID", member);
                         if (card) {
                             let email = card.getProperty("PrimaryEmail");
                             if (!email) {
@@ -785,7 +769,12 @@ var sync = {
                         }
                         m++;
                     }
-                    list.setMembersByPropertyList("X-DAV-UID", newMembers);
+                    
+                    // if any of the to-be-removed members are not members of the local list, they are skipt
+                    // if any of the to-be-added members are already members of the local list, they are skipt
+                    list.removeListMembers("X-DAV-UID", removedMembers);
+                    list.addListMembers("X-DAV-UID", newMembers);
+                    syncData.target.modifyItem(list);
                 }
             }
         }            
@@ -847,7 +836,7 @@ var sync = {
                             let isAdding = (changes[i].status == "added_by_user");
                             if (!permissionError[changes[i].status]) { //if this operation failed already, do not retry
 
-                                let card = syncData.target.getItem(changes[i].itemId);
+                                let card = await syncData.target.getItem(changes[i].itemId);
                                 if (card) {
                                     if (card.isMailList && !syncGroups) {                                        
                                         // Conditionally break out of the switch early, but do
@@ -879,7 +868,7 @@ var sync = {
 
                             if (permissionError[changes[i].status]) {
                                 //we where not allowed to add or modify that card, remove it, we will get a fresh copy on the following revert
-                                let card = syncData.target.getItem(changes[i].itemId);
+                                let card = await syncData.target.getItem(changes[i].itemId);
                                 if (card) syncData.target.deleteItem(card);
                                 permissionErrors++;
                             }
