@@ -17,14 +17,15 @@ var tools = {
         } catch (e) {
             //Components.utils.reportError(e);                
         }
+        
         // always use the core email field values, they could have been mod outside by the user,
         // not knowing that we store our stuff in X-DAV-JSON-Emails
         let emailFields = ["PrimaryEmail", "SecondEmail"];
         for (let i = 0; i < emailFields.length; i++) {
-            let email = aCard.getProperty(emailFields[i],"").trim();
+            let email = aCard.getProperty(emailFields[i], "");
             if (email) {
-                if (emailData.length > i) emailData[i].value = email;
-                else emailData.push({value: email, meta: []});
+                if (emailData.length > i) emailData[i].value = email.trim();
+                else emailData.push({value: email.trim(), meta: []});
             }
         }    
            
@@ -32,18 +33,14 @@ var tools = {
     },
     
     getPhoneNumbersFromCard: function (aCard) { //return array of objects {meta, value}
-        let phones = aCard.getProperty("X-DAV-JSON-Phones","").trim();
+        let phones = [];
         try {
-            if (phones) {
-                return JSON.parse(phones);
-            }
+            phones = JSON.parse(aCard.getProperty("X-DAV-JSON-Phones","").trim());
+            return phones;
         } catch (e) {
             //Components.utils.reportError(e);                
         }
-                
-        phones = [];
-        
-        
+
         //So this card is not a "DAV" card: Get the phone numbers from current numbers stored in 
         //CellularNumber, FaxNumber, PagerNumber, WorkPhone, HomePhone"},
         let todo = [
@@ -55,9 +52,9 @@ var tools = {
         ];
             
         for (let data of todo) {
-            let phone = aCard.getProperty(data.field,"").trim();
+            let phone = aCard.getProperty(data.field, "");
             if (phone) {
-                phones.push({value: phone, meta: data.meta});
+                phones.push({value: phone.trim(), meta: data.meta});
             }
         }
         return phones;
@@ -170,7 +167,8 @@ var tools = {
 
 
     getEmailsFromJSON: function (emailDataJSON) {
-        let emailFields = {};
+        // prepare defaults
+        let emailFields = {PrimaryEmail:[], SecondEmail:[]};
 
         if (emailDataJSON) {
             try {
@@ -178,7 +176,6 @@ var tools = {
                 // For compatibility with the Phones, we return arrays, even though we only return
                 // one element per array.
                 let emailData = JSON.parse(emailDataJSON);
-                emailFields = {PrimaryEmail:[], SecondEmail:[]};
                 
                 for (let d=0; d < emailData.length && d < 2; d++) {
                     let field = (d==0) ? "PrimaryEmail" : "SecondEmail";
@@ -196,22 +193,26 @@ var tools = {
 
 
     getPhoneNumbersFromJSON: function (phoneDataJSON) {
-        let phoneFields = {};
+        let phoneMap = [
+            {meta: "CELL", field: "CellularNumber"},
+            {meta: "FAX", field: "FaxNumber"},
+            {meta: "PAGER", field: "PagerNumber"},
+            {meta: "WORK", field: "WorkPhone"},
+            {meta: "", field: "HomePhone"},
+            ];
 
+        // prepare defaults
+        let phoneFields = {};
+        for (let m=0; m < phoneMap.length; m++) {
+            phoneFields[phoneMap[m].field] = [];            
+        }
+                
         if (phoneDataJSON) {
             try {
                 //we first search and remove CELL, FAX, PAGER and WORK from the list and put the remains into HOME
                 let phoneData = JSON.parse(phoneDataJSON);
-                let phoneMap = [
-                    {meta: "CELL", field: "CellularNumber"},
-                    {meta: "FAX", field: "FaxNumber"},
-                    {meta: "PAGER", field: "PagerNumber"},
-                    {meta: "WORK", field: "WorkPhone"},
-                    {meta: "", field: "HomePhone"},
-                    ];
-                
-                for (let m=0; m < phoneMap.length; m++) {
-                    phoneFields[phoneMap[m].field] = [];            
+
+                for (let m=0; m < phoneMap.length; m++) {        
                     for (let d=phoneData.length-1; d >= 0; d--) {
                         if (phoneData[d].meta.includes(phoneMap[m].meta) || phoneMap[m].meta == "") {
                             phoneFields[phoneMap[m].field].unshift(phoneData[d].value);
@@ -349,7 +350,7 @@ var tools = {
         let vCardData = dav.vCard.parse(vCard);
 
         //check if contact or mailinglist
-        if (!dav.tools.vCardIsMailingList (syncData, id, null, vCard, vCardData, etag)) {
+        if (!(await dav.tools.vCardIsMailingList (syncData, id, null, vCard, vCardData, etag))) {
             //prepare new contact card
             let card = syncData.target.createNewCard();
             card.setProperty("X-DAV-HREF", id);
@@ -357,7 +358,7 @@ var tools = {
             card.setProperty("X-DAV-VCARD", vCard);
 
             await dav.tools.setThunderbirdCardFromVCard(syncData, card, vCardData);
-            syncData.target.addItem(card);
+            await syncData.target.addItem(card);
         }
     },
 
@@ -366,10 +367,10 @@ var tools = {
         let vCardData = dav.vCard.parse(vCard);
 
         //get card
-        let card = syncData.target.getItemFromProperty("X-DAV-HREF", id);
+        let card = await syncData.target.getItemFromProperty("X-DAV-HREF", id);
         if (card) {
             //check if contact or mailinglist to update card
-            if (!dav.tools.vCardIsMailingList (syncData, id, card, vCard, vCardData, etag)) {          
+            if (!(await dav.tools.vCardIsMailingList (syncData, id, card, vCard, vCardData, etag))) {
                 //get original vCard data as stored by last update from server
                 let oCard = card.getProperty("X-DAV-VCARD");
                 let oCardData = oCard ? dav.vCard.parse(oCard) : null;
@@ -390,7 +391,7 @@ var tools = {
     
     
     //check if vCard is a mailinglist and handle it
-    vCardIsMailingList: function (syncData, id, _list, vCard, vCardData, etag) {
+    vCardIsMailingList: async function (syncData, id, _list, vCard, vCardData, etag) {
         if (vCardData.hasOwnProperty("X-ADDRESSBOOKSERVER-KIND") && vCardData["X-ADDRESSBOOKSERVER-KIND"][0].value == "group") { 
             if (!syncData.accountData.getAccountProperty("syncGroups")) {
                 //user did not enable group sync, so do nothing, but return true so this card does not get added as a real card
@@ -406,7 +407,7 @@ var tools = {
                 list.setProperty("X-DAV-HREF", id);
                 list.setProperty("X-DAV-UID", vCardInfo.uid);
                 list.setProperty("ListName",  vCardInfo.name);
-                syncData.target.addItem(list);
+                await syncData.target.addItem(list);
             } else {
                 list.setProperty("ListName",  vCardInfo.name);
                 syncData.target.modifyItem(list);
@@ -891,8 +892,10 @@ var tools = {
 
     //update send from server to client
     setThunderbirdCardFromVCard: async function(syncData, card, vCardData, oCardData = null) {
-        if (TbSync.prefs.getIntPref("log.userdatalevel") > 2) TbSync.dump("JSON from vCard", JSON.stringify(vCardData));
-        //if (oCardData) TbSync.dump("JSON from oCard", JSON.stringify(oCardData));
+        if (TbSync.prefs.getIntPref("log.userdatalevel") > 2) {
+            TbSync.dump("JSON from vCard", JSON.stringify(vCardData));
+            TbSync.dump("JSON from oCard", oCardData ? JSON.stringify(oCardData) : "");
+        }
 
         for (let f=0; f < dav.tools.supportedProperties.length; f++) {
             //Skip sync fields that have been added after this folder was created (otherwise we would delete them)
@@ -914,7 +917,11 @@ var tools = {
                             if (newServerValue) {
                                 let type = "";
                                 try {
-                                    type = vCardData[vCardField.item][0].meta.type[0].toLowerCase();
+                                    // Try to get the type from the the meta field but only use a given subtype (cut of leading "image/").
+                                    // See draft: https://tools.ietf.org/id/draft-ietf-vcarddav-vcardrev-02.html#PHOTO
+                                    // However, no mentioning of this in final RFC2426 for vCard 3.0.
+                                    // Also make sure, that the final type does not include any non alphanumeric chars.
+                                    type = vCardData[vCardField.item][0].meta.type[0].toLowerCase().split("/").pop().replace(/\W/g, "");
                                 } catch (e) {
                                     Components.utils.reportError(e);
                                 }
@@ -945,9 +952,9 @@ var tools = {
                                 }
                             } else {
                                 //clear
-                                card.deleteProperty("PhotoName");
-                                card.deleteProperty("PhotoType");
-                                card.deleteProperty("PhotoURI");
+                                card.setProperty("PhotoName", "");
+                                card.setProperty("PhotoType", "");
+                                card.setProperty("PhotoURI", "");
                             }
                         }
                         break;
@@ -960,9 +967,9 @@ var tools = {
                                 card.setProperty("BirthMonth", bday[2]);
                                 card.setProperty("BirthDay", bday[3]);
                             } else {
-                                card.deleteProperty("BirthYear");
-                                card.deleteProperty("BirthMonth");
-                                card.deleteProperty("BirthDay");
+                                card.setProperty("BirthYear", "");
+                                card.setProperty("BirthMonth", "");
+                                card.setProperty("BirthDay", "");
                             }
                         }
                         break;
@@ -981,30 +988,27 @@ var tools = {
                                     tbData = dav.tools.getPhoneNumbersFromJSON(newServerValue);
                                     break;
                             }
-                                
+
                             for (let field in tbData) {
                                 if (tbData.hasOwnProperty(field)) {
                                     //set or delete TB Property
-                                    if (  tbData[field].length > 0 ) {
+                                    if (tbData[field].length > 0) {
                                         card.setProperty(field, tbData[field].join(", "));
                                     } else {
-                                        card.deleteProperty(field);
+                                        card.setProperty(field, "");
                                     }                            
                                 }
                             }
                         }
-
+                        
                     default:
                         {
                             if (newServerValue) {
                                 //set
                                 card.setProperty(property, newServerValue);
                             } else {
-                                //clear (del if possible)
+                                //clear
                                 card.setProperty(property, "");
-                                try {
-                                    card.deleteProperty(property);
-                                } catch (e) {}
                             }
                         }
                         break;
@@ -1148,6 +1152,8 @@ var tools = {
                             dav.tools.updateValueOfVCard(syncData, property, vCardData, vCardField, card.getProperty("PhotoURI", ""));
                             this.setDefaultMetaButKeepCaseIfPresent({value : "uri", type : type}, vCardData[vCardField.item][0]);
                             TbSync.eventlog.add("info", syncData.eventLogInfo, "after photo ("+vCardField.item+")", JSON.stringify(vCardData));
+                        } else {
+                            dav.tools.updateValueOfVCard(syncData, property, vCardData, vCardField, "");                            
                         }
                     }
                     break;
@@ -1255,21 +1261,21 @@ var tools = {
         let uidProp = card.getProperty("X-DAV-UID");
         let uidItem = ""; try { uidItem = vCardData["uid"][0].value; } catch (e) {}
         if (!uidItem && !uidProp) {
-            TbSync.eventlog.add("info", syncData.eventLogInfo, "Generated missing UID for card <"+listName+">");
+            TbSync.eventlog.add("info", syncData.eventLogInfo, "Generated missing UID for card");
             let uid = TbSync.generateUUID();
             card.setProperty("X-DAV-UID", uid);
             vCardData["uid"] = [{"value": uid}];
             syncData.target.modifyItem(card);
         } else if (!uidItem && uidProp) {
             vCardData["uid"] = [{"value": uidProp}];
-            TbSync.eventlog.add("info", syncData.eventLogInfo, "Updating item uid from uid property for card <"+listName+">", JSON.stringify({uidProp, uidItem}));
+            TbSync.eventlog.add("info", syncData.eventLogInfo, "Updating item uid from uid property for card", JSON.stringify({uidProp, uidItem}));
         } else if (uidItem && !uidProp) {
             card.setProperty("X-DAV-UID", uidItem);
-            TbSync.eventlog.add("info", syncData.eventLogInfo, "Updating uid property from item uid of card <"+listName+">", JSON.stringify({uidProp, uidItem}));
+            TbSync.eventlog.add("info", syncData.eventLogInfo, "Updating uid property from item uid of card", JSON.stringify({uidProp, uidItem}));
             syncData.target.modifyItem(card);
         } else if (uidItem != uidProp) {
             card.setProperty("X-DAV-UID", uidItem);
-            TbSync.eventlog.add("info", syncData.eventLogInfo, "Updating uid property from item uid of card <"+listName+">", JSON.stringify({uidProp, uidItem}));
+            TbSync.eventlog.add("info", syncData.eventLogInfo, "Updating uid property from item uid of card", JSON.stringify({uidProp, uidItem}));
             syncData.target.modifyItem(card);
         }
 
